pitchtools.all_are_named_chromatic_pitch_tokens
===============================================

.. autofunction:: abjad.tools.pitchtools.all_are_named_chromatic_pitch_tokens.all_are_named_chromatic_pitch_tokens
